FrustumCuller

Struct FrustumCuller 

pub struct FrustumCuller<S> { /* private fields */ }

Implementations

Source

impl<S: BaseFloat> FrustumCuller<S>

pub fn new() -> Self

Creates an identity frustum culler. This is equivalent to calling the from_matrix method passing an identity matrix.

pub fn from_perspective(perspective: Perspective<S>) -> Self

Creates a frustum culler from a given perspective frustum configuration.

pub fn from_perspective_fov(perspective: PerspectiveFov<S>) -> Self

Creates a frustum culler from a given PerspectiveFov configuration.

pub fn from_ortho(ortho: Ortho<S>) -> Self

pub fn from_matrix(m: Matrix4<S>) -> Self

Creates a FrustumCuller from an arbitrary matrix, from which the frustum planes are computed.

pub fn test_point(&self, point: Vector3<S>) -> Intersection

Test wether a 3D point lies inside of the frustum

pub fn test_sphere<T>(&self, sphere: T) -> Intersection
where T: Into<Sphere<S>>,

Returns the result of testing the intersection of the frustum with a sphere, defined by a center point (center) and a radius (radius).

This method will distinguish between a partial intersection and a total intersection.

pub fn test_bounding_box<T>(&self, aab: T) -> Intersection
where T: Into<BoundingBox<S>>,

Tests wether a given axis aligned bounding box intersects with the Frustum. There is a distinction between partial intersection and full intersection, which is given by the values of the Intersection enum.