Struct cgmath_culling::FrustumCuller
[−]
[src]
pub struct FrustumCuller<S> { /* fields omitted */ }
Methods
impl<S: BaseFloat> FrustumCuller<S>[src]
pub fn from_perspective(perspective: Perspective<S>) -> Self[src]
pub fn from_perspective_fov(perspective: PerspectiveFov<S>) -> Self[src]
pub fn from_ortho(ortho: Ortho<S>) -> Self[src]
pub fn test_point(&self, point: Vector3<S>) -> bool[src]
Test wether a 3D point lies inside of the frustum
pub fn test_sphere(&self, center: Vector3<S>, radius: S) -> bool[src]
Tests wether a sphere lies inside the frustum.
This method doesn't distinguish between total and partial intersection with the frustum. In
order to make this distinction, use the intersect_sphere method instead.
pub fn test_aab(&self, min: Vector3<S>, max: Vector3<S>) -> bool[src]
Test wether an axis aligned box, defined by is minimum (min) and maximum (max) points,
lies inside or outside the frustum.
This method won't distinguish between partial or total intersection. In order to obtain
this information, use the intersect_aab method instead.
pub fn intersect_sphere(&self, center: Vector3<S>, radius: S) -> Intersection[src]
Returns the result of testing the intersection of the frustum with a sphere, defined by a
center point (center) and a radius (radius).
This method will distinguish between a partial intersection and a total intersection.
pub fn intersect_aab(&self, min: Vector3<S>, max: Vector3<S>) -> Intersection[src]